Label annotation element definition (sarpy.annotation.label)
============================================================

.. automodule:: sarpy.annotation.label
    :members:
    :show-inheritance:
    :inherited-members:
